util/intelp2m: Fix typos

Change-Id: I7210fb44ed54d365181ca23c6b92d2269dc8a697
Signed-off-by: Benjamin Doron <benjamin.doron00@gmail.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/45007
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Reviewed-by: Angel Pons <th3fanbus@gmail.com>
diff --git a/util/intelp2m/description.md b/util/intelp2m/description.md
index 9ca56b9..1aaee40 100644
--- a/util/intelp2m/description.md
+++ b/util/intelp2m/description.md
@@ -23,9 +23,9 @@
 		0 - inteltool.log (default)
 		1 - gpio.h
 		2 - your template
-(shell)$ ./intelp2m -t 1 -file coreboot/src/mainboard/youboard/gpio.h
+(shell)$ ./intelp2m -t 1 -file coreboot/src/mainboard/yourboard/gpio.h
 ```
-You can also add add a template to 'parser/template.go' for your file type with
+You can also add a template to 'parser/template.go' for your file type with
 the configuration of the pads.
 
 platform type is set using the -p option (Sunrise by default):
@@ -35,7 +35,7 @@
 		snr - Sunrise PCH with Skylake/Kaby Lake CPU
 		lbg - Lewisburg PCH with Xeon SP CPU
 		apl - Apollo Lake SoC
-		cnl - CannonLake-LP or Whiskeylake/Coffelake/Cometlake-U SoC
+		cnl - CannonLake-LP or Whiskeylake/Coffeelake/Cometlake-U SoC
 	(default "snr")
 
 (shell)$ ./intelp2m -p <platform> -file path/to/inteltool.log
diff --git a/util/intelp2m/main.go b/util/intelp2m/main.go
index a7bbc91..511f54d 100644
--- a/util/intelp2m/main.go
+++ b/util/intelp2m/main.go
@@ -67,9 +67,9 @@
 		"\tsnr - Sunrise PCH or Skylake/Kaby Lake SoC\n"+
 		"\tlbg - Lewisburg PCH with Xeon SP\n"+
 		"\tapl - Apollo Lake SoC\n"+
-		"\tcnl - CannonLake-LP or Whiskeylake/Coffelake/Cometlake-U SoC\n")
+		"\tcnl - CannonLake-LP or Whiskeylake/Coffeelake/Cometlake-U SoC\n")
 
-	filedstyle :=  flag.String("fld", "none", "set fileds macros style:\n"+
+	fieldstyle :=  flag.String("fld", "none", "set fields macros style:\n"+
 		"\tcb  - use coreboot style for bit fields macros\n"+
 		"\tfsp - use fsp style\n"+
 		"\traw - do not convert, print as is\n")
@@ -106,8 +106,8 @@
 		os.Exit(1)
 	}
 
-	if config.FldStyleSet(*filedstyle) != 0 {
-		fmt.Printf("Error! Unknown bit fields style option -%s!\n", *filedstyle)
+	if config.FldStyleSet(*fieldstyle) != 0 {
+		fmt.Printf("Error! Unknown bit fields style option -%s!\n", *fieldstyle)
 		os.Exit(1)
 	}
diff --git a/util/intelp2m/fields/cb/cb.go b/util/intelp2m/fields/cb/cb.go
index 2a87cda..3bda62e 100644
--- a/util/intelp2m/fields/cb/cb.go
+++ b/util/intelp2m/fields/cb/cb.go
@@ -19,11 +19,11 @@
 }
 
 // generate - wrapper for generating bitfield macros string
-// fileds : field structure
-func generate(fileds ...*field) {
+// fields : field structure
+func generate(fields ...*field) {
 	macro := common.GetMacro()
 	var allhidden bool = true
-	for _, field := range fileds {
+	for _, field := range fields {
 		if field.unhide {
 			allhidden = false
 			macro.Or()
diff --git a/util/intelp2m/fields/fsp/fsp.go b/util/intelp2m/fields/fsp/fsp.go
index fa26b5a..360333a 100644
--- a/util/intelp2m/fields/fsp/fsp.go
+++ b/util/intelp2m/fields/fsp/fsp.go
@@ -15,10 +15,10 @@
 }
 
 // generate - wrapper for generating bitfield macros string
-// fileds : field structure
-func generate(fileds ...*field) {
+// fields : field structure
+func generate(fields ...*field) {
 	macro := common.GetMacro()
-	for _, field := range fileds {
+	for _, field := range fields {
 		if field.override != nil {
 			// override if necessary
 			field.override(field.configmap, field.value)